@@ -120,8 +120,11 @@ impl KrakenWS {
             let (writer, reader) = client.split();
             let send_ws = rx.map(|x| Ok(Message::text(x.to_string()))).forward(writer);
             let ws_callback = reader.for_each(|msg| async {
-                let json: Value = serde_json::from_str(&msg.unwrap().to_string()).unwrap();
-                event_callback(json);
+                if let Ok(message) = msg {
+                    if let Ok(json) = serde_json::from_str(&message.to_string()) {
+                        event_callback(json);
+                    }
+                }
             });
             pin_mut!(send_ws, ws_callback);
             futures::future::select(send_ws, ws_callback).await;
